@@ -133,7 +133,57 @@ new_types!(
     u7  (7, u8)   => [u8, u16, u32, u64, u128],
     u9  (9, u16)  => [u16, u32, u64, u128],
     u10 (10, u16) => [u16, u32, u64, u128],
-    u11 (11, u16) => [u16, u32, u64, u128]
+    u11 (11, u16) => [u16, u32, u64, u128],
+    u12 (12, u16) => [u16, u32, u64, u128],
+    u13 (13, u16) => [u16, u32, u64, u128],
+    u14 (14, u16) => [u16, u32, u64, u128],
+    u15 (15, u16) => [u16, u32, u64, u128],
+    u17 (17, u32) => [u32, u64, u128],
+    u18 (18, u32) => [u32, u64, u128],
+    u19 (19, u32) => [u32, u64, u128],
+    u20 (20, u32) => [u32, u64, u128],
+    u21 (21, u32) => [u32, u64, u128],
+    u22 (22, u32) => [u32, u64, u128],
+    u23 (23, u32) => [u32, u64, u128],
+    u24 (24, u32) => [u32, u64, u128],
+    u25 (25, u32) => [u32, u64, u128],
+    u26 (26, u32) => [u32, u64, u128],
+    u27 (27, u32) => [u32, u64, u128],
+    u28 (28, u32) => [u32, u64, u128],
+    u29 (29, u32) => [u32, u64, u128],
+    u30 (30, u32) => [u32, u64, u128],
+    u31 (31, u32) => [u32, u64, u128],
+    u33 (33, u64) => [u64, u128],
+    u34 (34, u64) => [u64, u128],
+    u35 (35, u64) => [u64, u128],
+    u36 (36, u64) => [u64, u128],
+    u37 (37, u64) => [u64, u128],
+    u38 (38, u64) => [u64, u128],
+    u39 (39, u64) => [u64, u128],
+    u40 (40, u64) => [u64, u128],
+    u41 (41, u64) => [u64, u128],
+    u42 (42, u64) => [u64, u128],
+    u43 (43, u64) => [u64, u128],
+    u44 (44, u64) => [u64, u128],
+    u45 (45, u64) => [u64, u128],
+    u46 (46, u64) => [u64, u128],
+    u47 (47, u64) => [u64, u128],
+    u48 (48, u64) => [u64, u128],
+    u49 (49, u64) => [u64, u128],
+    u50 (50, u64) => [u64, u128],
+    u51 (51, u64) => [u64, u128],
+    u52 (52, u64) => [u64, u128],
+    u53 (53, u64) => [u64, u128],
+    u54 (54, u64) => [u64, u128],
+    u55 (55, u64) => [u64, u128],
+    u56 (56, u64) => [u64, u128],
+    u57 (57, u64) => [u64, u128],
+    u58 (58, u64) => [u64, u128],
+    u59 (59, u64) => [u64, u128],
+    u60 (60, u64) => [u64, u128],
+    u61 (61, u64) => [u64, u128],
+    u62 (62, u64) => [u64, u128],
+    u63 (63, u64) => [u64, u128]
 );
 
 impl<
@@ -320,7 +370,7 @@ macro_rules! bit_struct_impl {
 /// the macro. The catch is a **base type** must be specified. Valid base types are
 /// u{8,16,32,64,128}. The elements stored in the struct are statically guaranteed to not
 /// exceed the number of bits in the base type. This means we cannot store a `u16` in a `u8`, but
-/// it also means we cannot store 9 [bit_struct::u1]s in a u8.
+/// it also means we cannot store 9 `u1`s in a u8.
 ///
 /// Elements start at the top of the number (for a u16 this would be the 15th bit) and progress
 /// down.
